@@ -82,3 +82,43 @@ sub new
 # keep require happy
 1
 __END__
+
+=head1 NAME
+
+Module::FromPerlVer::Extract - common methods for extractors.
+
+=head1 SYNOPSIS
+
+    # see also Module::FromPerlVer::Extract for 
+    # valid arguments.
+    #
+    # the purpose of this module is keeping new
+    # and friends out of M::PFV.
+
+    my $type    = 'Dir';    # or 'Git'
+
+    my $class   = qualify $type, 'Module::FromPerlVer';
+
+    # call construct then dispatch EVERY::LAST::init.
+
+    my $extract = $class->new( $argz );
+
+    # acquire, store, delete a value stored in
+    # the extractor.
+
+    my $stored  = $extract->value( 'foobar' );
+
+    my $new_val = $extract->value( foobar => $value );
+
+    my $old_val = $extract->value( foobar => undef  );
+
+
+
+=head1 SEE ALSO
+
+=over 4
+
+=item Module::FromPerlVer::Extract 
+
+=back
+
